@@ -6,7 +6,7 @@ _client_session = None
 
 class CommError(Exception):
 
-    def __init__(msg, payload = None):
+    def __init__(self, msg, payload=None):
         super().__init__(msg)
         self.payload = payload
 
