@@ -37,6 +37,7 @@ class Code(str, Enum):
     InvalidValue = "InvalidValue"
     NoSegment = "NoSegment"
     TooBig = "TooBig"
+    NoMatch = "NoMatch"
 
 
 class Response(BaseModel):
@@ -87,9 +88,14 @@ class NearestResponse(Response):
         return cls(code=code, waypoints=waypoints)
 
 
+class Step(BaseModel):
+    geometry: str = None
+
+
 class Leg(BaseModel):
     distance: float
     duration: float
+    steps: List[Step] = []
 
 
 class Route(BaseModel):
@@ -124,6 +130,11 @@ class RouteResponse(Response):
             for j in range(0, ll):
                 lfb = rfb.Legs(j)
                 leg = Leg(duration=lfb.Duration(), distance=lfb.Distance())
+                sl = lfb.StepsLength()
+                for s in range(0, sl):
+                    sfb = lfb.Steps(s)
+                    step = Step(geometry = sfb.Geometry())
+                    leg.steps.append(step)
                 route.legs.append(leg)
             routes.append(route)
         return cls(code=code, routes=routes, waypoints=waypoints)
@@ -219,7 +230,7 @@ class API:
             d = None
             try:
                 d = await aiorequests.http_get_json(url)
-            except aiorequest.CommError as ce:
+            except aiorequests.CommError as ce:
                 logging.error(f'err calling {url}: {ce}')
                 if ce.payload:
                     return responseCls.from_dict(ce.payload)
@@ -236,9 +247,9 @@ class API:
         elif output_format == 'flatbuffers':
             return responseCls.from_fb(await aiorequests.http_get_raw(url))
 
-    async def nearest(self, loc: LatLng, output_format: OutputFormat, radius: Optional[float] = None, bearing: Optional[float] = None) -> NearestResponse:
+    async def nearest(self, loc: LatLng, output_format: OutputFormat, number: int = 1, radius: Optional[float] = None, bearing: Optional[float] = None) -> NearestResponse:
         url = f'{self.base_url}/nearest/v1/driving/{loc.lng},{loc.lat}.{output_format}'
-        params = {}
+        params = {'number': number}
         if radius is not None:
             params['radiuses'] = radius
         if bearing is not None:
@@ -272,7 +283,7 @@ class API:
         url += "?" + urlencode(params)
         return await self._call(url, output_format, MatchResponse)
 
-    async def route(self, coords: List[LatLng], output_format: OutputFormat, geometry: Geometry = Geometry.polyline) -> RouteResponse:
+    async def route(self, coords: List[LatLng], output_format: OutputFormat, geometry: Geometry = Geometry.polyline, steps: bool = False) -> RouteResponse:
         coords_param = ';'.join([f'{c.lng},{c.lat}' for c in coords])
-        url = f'{self.base_url}/route/v1/driving/{coords_param}.{output_format}?overview=full&geometries={geometry}'
+        url = f'{self.base_url}/route/v1/driving/{coords_param}.{output_format}?overview=full&geometries={geometry}&steps={steps}'
         return await self._call(url, output_format, RouteResponse)
