@@ -45,6 +45,11 @@ def test_route_response():
                     {
                         'distance': 1.0,
                         'duration': 1.0,
+                        'steps':[
+                            {
+                                'geometry':'whocares2',
+                            }
+                        ],
                     },
                 ],
             },
@@ -52,6 +57,7 @@ def test_route_response():
     }
     r = RouteResponse(**mock)
     assert r.routes[0].geometry == 'whocares'
+    assert r.routes[0].legs[0].steps[0].geometry == 'whocares2'
 
 
 def test_table_response():
